///////////////////////////////////////
// Common functions
///////////////////////////////////////

//
// Load dimensions from prefs
//
function LoadFromPrefs() {
	// Load dimensions from prefs
	var prefMgr = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);
	var prefs = prefMgr.getBranch("extensions.firesizer.dimensionlist.");
	var dimensionlist = prefs.getCharPref("outer");
	var dimensions = dimensionlist.split(";");
	// Sort the dimension list
	dimensions.sort(SortByLabel);
	return dimensions;
}


//
// Save dimensions to prefs
//
function SaveToPrefs(dimensions) {
	dimensions = deDupe(dimensions);	// Remove duplicates
	dimensions.sort(SortByLabel);		// Sort the dimension list
	// Save to prefs
	var prefMgr = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);
	var prefs = prefMgr.getBranch("extensions.firesizer.dimensionlist.");
	prefs.setCharPref("outer", dimensions.join(";"));
}


//
// Add dimension to list
//
function AddDimension(width, height) {
	var dimensions = LoadFromPrefs();
	dimensions[dimensions.length++] = width + "x" + height;
	SaveToPrefs(dimensions);
}


////////////////////////////////////////
// Callback functions

//
// Sort dimension list by label, callback from sort method
//
function SortByLabel(a, b) {
	var aSqPx = getSqPx(a);
	var bSqPx = getSqPx(b);
	if      ( aSqPx > bSqPx ) { return 1;  }
	else if ( aSqPx < bSqPx ) { return -1; }
	else                      { return 0;  }
}


////////////////////////////////////////
// Utility functions

//
// Dedupe a list of dimensions
//
function deDupe(dimensions) {
	var unique = new Object();
	for( var i=0; i < dimensions.length; i++ ) {
		unique[ dimensions[i] ] = 1;
	}
	var result = new Array();
	for( var dim in unique ) {
		result[result.length++] = dim;
	}
	return result;
}


//
// Calculate square pixels from the dimensions
//
function getSqPx(dimstr) {
	var dim = dimstr.split("x");
	return Number(dim[0]) * Number(dim[1]);
}


//
// Return true if string is empty, false if not
//
function isEmpty(str) {
	if ( str == null || str == "" ) { 
		return true; 
	} else {
		return false;
	}
}


